=================================================================
:mod:`cloud_sptheme.ext.relbar_toc` - adds TOC entry to relbar
=================================================================

.. module:: cloud_sptheme.ext.relbar_toc
    :synopsis: adds TOC entry to right side of relbar

Overview
========
This Sphinx extension automatically inserts a Table Of Contents
entry into the navigation bar (``relbar``) at the top and bottom of all pages;
similar to the old python documentation format.

This is mainly useful when the title link in the navigation bar has been redirected
to page other than Table Of Contents
(such as allowed by the ``roottarget`` option of the :doc:`/cloud_theme`).
